package mew

  1. Overview
  2. Docs

Module type Key.SSource

type t
type code
type modifier
type modifiers
val create : code:code -> modifiers:modifiers -> t
val create_modifiers : modifier list -> modifiers
val code : t -> code
val modifiers : t -> modifiers
val modifier : key:t -> modifier:modifier -> bool
val compare : t -> t -> int
val to_string : t -> string
include Hashtbl.HashedType with type t := t
val equal : t -> t -> bool

The equality predicate used to compare keys.

val hash : t -> int

A hashing function on keys. It must be such that if two keys are equal according to equal, then they have identical hash values as computed by hash.

The hash value of a key should remain constant as long as the key is in the table. In particular, if the hash function depends on mutable key data, then that data must not be mutated while the key is in the table. Similarly, as the hash function may be called while the table itself is being modified, it should avoid accessing the table as part of its computation.

Examples: suitable (equal, hash) pairs for arbitrary key types include

  • ((=), hash) for comparing objects by structure (provided objects do not contain floats)
  • ((fun x y -> compare x y = 0), hash) for comparing objects by structure and handling Stdlib.nan correctly
  • ((==), hash) for comparing objects by physical equality (e.g. for mutable or cyclic objects).